@@ -48,8 +48,6 @@ def clean(line):
 
 def clean_lines(lines):
     for line in lines:
-        if line is None:
-            yield None
-        else:
+        if not line.is_ignore:
             clean(line)
-            yield line
+        yield line
