@@ -17,7 +17,7 @@ LIST_REGEX = re.compile(r"^\s*([*-]|\d+\.) (\[[x ]?] )?")
 QUOTE_REGEX = re.compile(r"^>+\s*")
 HTML_REGEX = re.compile(r"<.+?>")
 
-URL_REGEX = re.compile(r"<?(http|https|ftp)://[-a-zA-Z0-9()@:%_+.~#?&/=]+>?")
+URL_REGEX = re.compile(r"<?(http|https|ftp)://[-a-zA-Z0-9@:%_+.~#?&/=]+>?")
 LINK_REGEX = re.compile(r"(!?\[)(.*?)(]\(.*?\))")
 CODE_REGEX = re.compile(r"`.+?`")
 SYMBOL_REGEX = re.compile(r"(\*|___|__|~)")  # ASCII Symbols to clean
